@@ -1,26 +1,23 @@
-from platon import Web3
+from typing import TYPE_CHECKING
 from platon.datastructures import AttributeDict
 
 from platon_aide.base.module import Module
 from platon_aide.utils import contract_transaction
-from platon_aide.economic import Economic, new_economic
-from platon_aide.staking import Staking
+
+if TYPE_CHECKING:
+    from platon_aide import Aide
 
 
 class Delegate(Module):
 
-    def __init__(self, web3: Web3, economic: Economic = None):
-        super().__init__(web3)
-        self.contract_address = self.web3.ppos.delegate.delegateBase.address
-        self._module_type = 'inner-contract'
-        self._result_type = 'event'
-        self._get_node_info()
-        self._economic = new_economic(web3.debug.economic_config()) if not economic and hasattr(web3, 'debug') else economic
+    def __init__(self, aide: "Aide"):
+        super().__init__(aide, module_type='inner-contract')
+        self.ADDRESS = self.aide.web3.ppos.delegate.delegateBase.address
+        self.REWARD_ADDRESS = self.aide.web3.ppos.delegate.delegateReward.address
 
     @property
-    def _staking_block_number(self):
-        staking = Staking(self.web3)
-        return staking.staking_info.StakingBlockNum
+    def staking_block_number(self):
+        return self.aide.staking.staking_info.StakingBlockNum
 
     @contract_transaction()
     def delegate(self,
@@ -32,9 +29,9 @@ class Delegate(Module):
                  ):
         """ 委托节点，以获取节点的奖励分红
         """
-        amount = amount or self._economic.add_staking_limit
-        node_id = node_id or self._node_id
-        return self.web3.ppos.delegate.delegate(node_id, balance_type, amount)
+        amount = amount or self.aide.economic.delegate_limit
+        node_id = node_id or self.aide.node_id
+        return self.aide.web3.ppos.delegate.delegate(node_id, balance_type, amount)
 
     @contract_transaction(1005)
     def withdrew_delegate(self,
@@ -48,14 +45,14 @@ class Delegate(Module):
         撤回对节点的委托，可以撤回部分委托
         注意：因为节点可能进行过多次质押/撤销质押，会使得委托信息遗留，因此撤回委托时必须指定节点质押区块
         """
-        node_id = node_id or self._node_id
-        amount = amount or self._economic.add_staking_limit
-        staking_block_identifier = staking_block_identifier or self._staking_block_number
+        node_id = node_id or self.aide.node_id
+        amount = amount or self.aide.economic.delegate_limit
+        staking_block_identifier = staking_block_identifier or self.aide.staking.staking_info.StakingBlockNum
 
-        return self.web3.ppos.delegate.withdrew_delegate(node_id,
-                                                         staking_block_identifier,
-                                                         amount,
-                                                         )
+        return self.aide.web3.ppos.delegate.withdrew_delegate(node_id,
+                                                              staking_block_identifier,
+                                                              amount,
+                                                              )
 
     @contract_transaction(1006)
     def redeem_delegate(self,
@@ -65,7 +62,7 @@ class Delegate(Module):
         """
         领取已经解锁的委托金
         """
-        return self.web3.ppos.delegate.redeem_delegate()
+        return self.aide.web3.ppos.delegate.redeem_delegate()
 
     def get_delegate_info(self,
                           address=None,
@@ -75,12 +72,12 @@ class Delegate(Module):
         """ 获取地址对某个节点的某次质押的委托信息
         注意：因为节点可能进行过多次质押/撤销质押，会使得委托信息遗留，因此获取委托信息时必须指定节点质押区块
         """
-        if self.default_account:
-            address = address or self.default_account.address
-        node_id = node_id or self._node_id
-        staking_block_identifier = staking_block_identifier or self._staking_block_number
+        if self.aide.default_account:
+            address = address or self.aide.default_account.address
+        node_id = node_id or self.aide.node_id
+        staking_block_identifier = staking_block_identifier or self.aide.staking.staking_info.staking_block_number
 
-        delegate_info = self.web3.ppos.delegate.get_delegate_info(address, node_id, staking_block_identifier)
+        delegate_info = self.aide.web3.ppos.delegate.get_delegate_info(address, node_id, staking_block_identifier)
         if delegate_info == 'Query delegate info failed:Delegate info is not found':
             return None
         else:
@@ -91,9 +88,9 @@ class Delegate(Module):
                                ):
         """ 获取地址处于锁定期的委托信息
         """
-        address = address or self.default_account.address
+        address = address or self.aide.default_account.address
 
-        delegate_lock_info = self.web3.ppos.delegate.get_delegate_lock_info(address)
+        delegate_lock_info = self.aide.web3.ppos.delegate.get_delegate_lock_info(address)
         # todo: 根据实际情况补全
         if delegate_lock_info == 'Query delegate info failed:Delegate info is not found':
             return None
@@ -103,9 +100,9 @@ class Delegate(Module):
     def get_delegate_list(self, address=None):
         """ 获取地址的全部委托信息
         """
-        if self.default_account:
-            address = address or self.default_account.address
-        delegate_list = self.web3.ppos.delegate.get_delegate_list(address)
+        if self.aide.default_account:
+            address = address or self.aide.default_account.address
+        delegate_list = self.aide.web3.ppos.delegate.get_delegate_list(address)
         if delegate_list == 'Retreiving delegation related mapping failed:RelatedList info is not found':
             return []
         else:
@@ -118,7 +115,7 @@ class Delegate(Module):
                                  ):
         """ 提取委托奖励，会提取委托了的所有节点的委托奖励
         """
-        return self.web3.ppos.delegate.withdraw_delegate_reward()
+        return self.aide.web3.ppos.delegate.withdraw_delegate_reward()
 
     def get_delegate_reward(self,
                             address=None,
@@ -126,10 +123,10 @@ class Delegate(Module):
                             ):
         """ 获取委托奖励信息，可以根据节点id过滤
         """
-        if self.default_account:
-            address = address or self.default_account.address
+        if self.aide.default_account:
+            address = address or self.aide.default_account.address
         node_ids = node_ids or []
-        return self.web3.ppos.delegate.get_delegate_reward(address, node_ids)
+        return self.aide.web3.ppos.delegate.get_delegate_reward(address, node_ids)
 
 
 class DelegateInfo(AttributeDict):
