@@ -1,14 +1,14 @@
 from time import time
-from typing import Union, Literal
+from typing import TYPE_CHECKING, Union, Literal
 
-from platon import Web3
 from platon.datastructures import AttributeDict
 from platon_typing import HexStr, NodeID, BlockIdentifier
 
 from platon_aide.base.module import Module
 from platon_aide.utils import contract_transaction
 
-second = lambda: str(int(time()))
+if TYPE_CHECKING:
+    from platon_aide import Aide
 
 
 def to_attribute_proposal(proposal):
@@ -29,18 +29,15 @@ class Govern(Module):
     paramGasPrice: int = 2000000000000000
     cancelGasPrice: int = 3000000000000000
 
-    def __init__(self, web3: Web3):
-        super().__init__(web3)
-        self.contract_address = self.web3.pip.address
-        self._module_type = 'inner-contract'
-        self._result_type = 'event'
-        self._get_node_info()
+    def __init__(self, aide: "Aide"):
+        super().__init__(aide, module_type='inner-contract')
+        self.ADDRESS = self.aide.web3.pip.address
 
     def chain_version(self, version=None):
         """ 获取链上的版本信息，或者转换指定的版本信息
         支持以下形式：int: 66048, string: '1.2.0', list: [1, 2, 0]
         """
-        version = version or self.web3.pip.get_chain_version()
+        version = version or self.aide.web3.pip.get_chain_version()
         version_bytes = None
 
         if type(version) is int:
@@ -67,56 +64,56 @@ class Govern(Module):
     def version_proposal(self,
                          version: int,
                          voting_rounds: int = 4,
-                         pip_number: str = second(),
+                         pip_number: str = str(time()),
                          node_id: Union[NodeID, HexStr] = None,
                          txn=None,
                          private_key=None,
                          ):
         """ 提交版本提案，实现链上共识硬分叉版本的升级
         """
-        node_id = node_id or self._node_id
-        return self.web3.pip.submit_version_proposal(node_id, pip_number, version, voting_rounds)
+        node_id = node_id or self.aide.node_id
+        return self.aide.web3.pip.submit_version_proposal(node_id, pip_number, version, voting_rounds)
 
     @contract_transaction(default_txn={'gasPrice': paramGasPrice})
     def param_proposal(self,
                        module: str,
                        name: str,
                        value: str,
-                       pip_number: str = second(),
+                       pip_number: str = str(time()),
                        node_id: Union[NodeID, HexStr] = None,
                        txn=None,
                        private_key=None,
                        ):
         """ 提交参数提案，修改链上可治理参数
         """
-        node_id = node_id or self._node_id
-        return self.web3.pip.submit_param_proposal(node_id, pip_number, module, name, value)
+        node_id = node_id or self.aide.node_id
+        return self.aide.web3.pip.submit_param_proposal(node_id, pip_number, module, name, value)
 
     @contract_transaction(default_txn={'gasPrice': cancelGasPrice})
     def cancel_proposal(self,
                         proposal_id: str,
                         voting_rounds: int = 4,
                         node_id: Union[NodeID, HexStr] = None,
-                        pip_number: str = second(),
+                        pip_number: str = str(time()),
                         txn=None,
                         private_key=None,
                         ):
         """ 提交取消提案
         """
-        node_id = node_id or self._node_id
-        return self.web3.pip.submit_cancel_proposal(node_id, pip_number, voting_rounds, proposal_id)
+        node_id = node_id or self.aide.node_id
+        return self.aide.web3.pip.submit_cancel_proposal(node_id, pip_number, voting_rounds, proposal_id)
 
     @contract_transaction(default_txn={'gasPrice': textGasPrice})
     def text_proposal(self,
-                      pip_number: str = second(),
+                      pip_number: str = str(time()),
                       node_id: Union[NodeID, HexStr] = None,
                       txn=None,
                       private_key=None,
                       ):
         """ 提交文本提案，文本提案不对链上产生影响，仅做pip投票意见收集作用
         """
-        node_id = node_id or self._node_id
-        return self.web3.pip.submit_text_proposal(node_id, pip_number)
+        node_id = node_id or self.aide.node_id
+        return self.aide.web3.pip.submit_text_proposal(node_id, pip_number)
 
     @contract_transaction()
     def vote(self,
@@ -130,10 +127,10 @@ class Govern(Module):
              ):
         """ 对提案进行投票
         """
-        node_id = node_id or self._node_id
-        version = version or self._version
-        version_sign = version_sign or self._version_sign
-        return self.web3.pip.vote(node_id, proposal_id, option, version, version_sign)
+        node_id = node_id or self.aide.node_id
+        version = version or self.aide.node_version
+        version_sign = version_sign or self.aide.version_sign
+        return self.aide.web3.pip.vote(node_id, proposal_id, option, version, version_sign)
 
     @contract_transaction()
     def declare_version(self,
@@ -145,39 +142,34 @@ class Govern(Module):
                         ):
         """ 向链上声明节点版本，以获得参与共识出块的资格
         """
-        node_id = node_id or self._node_id
-        version = version or self._version
-        version_sign = version_sign or self._version_sign
-        return self.web3.pip.declare_version(node_id, version, version_sign)
+        node_id = node_id or self.aide.node_id
+        version = version or self.aide.node_version
+        version_sign = version_sign or self.aide.version_sign
+        return self.aide.web3.pip.declare_version(node_id, version, version_sign)
 
     def get_proposal(self, proposal_id: Union[bytes, HexStr]):
         """ 获取提案信息
         """
-        proposal = self.web3.pip.get_proposal(proposal_id)
+        proposal = self.aide.web3.pip.get_proposal(proposal_id)
         return to_attribute_proposal(proposal)
 
-    def get_active_proposal(self, proposal_type: Literal[2, 3] = None):
-        """ 获取提案信息
+    def get_newest_proposal(self, proposal_type: Literal[1, 2, 3, 4] = None):
+        """ 获取最新的激活状态的提案信息
         """
-        if proposal_type not in [2, 3]:
-            raise ValueError('unsupported proposal type')
-
-        block_number = self.web3.platon.block_number
+        block_number = self.aide.web3.platon.block_number
         proposal_list = self.proposal_list(proposal_type)
 
         proposals = [proposal for proposal in proposal_list if proposal.EndVotingBlock > block_number]
 
         if not proposals:
             return None
-        if len(proposals) > 1:
-            raise ValueError('wrong proposal data')
 
         return proposals[0]
 
     def get_proposal_result(self, proposal_id: Union[bytes, HexStr]):
         """ 获取提案投票结果信息
         """
-        proposal_result = self.web3.pip.get_proposal_result(proposal_id)
+        proposal_result = self.aide.web3.pip.get_proposal_result(proposal_id)
         if not proposal_result:
             raise ValueError('proposal is not found.')
         if type(proposal_result) is str:
@@ -195,7 +187,7 @@ class Govern(Module):
                            ):
         """ 获取提案实时投票信息
         """
-        proposal_votes = self.web3.pip.get_proposal_votes(proposal_id, block_identifier)
+        proposal_votes = self.aide.web3.pip.get_proposal_votes(proposal_id, block_identifier)
         if not proposal_votes:
             raise ValueError('proposal is not found.')
 
@@ -213,9 +205,10 @@ class Govern(Module):
     def proposal_list(self, proposal_type: Literal[1, 2, 3, 4] = None):
         """ 获取提案列表，可以根据提案类型过滤
         """
-        proposal_list = self.web3.pip.proposal_list()
-        if type(proposal_list) is not list:
-            raise ValueError('proposals is not found.')
+        proposal_list = self.aide.web3.pip.proposal_list()
+
+        if proposal_list == 'Object not found':
+            proposal_list = []
 
         proposals = [to_attribute_proposal(proposal) for proposal in proposal_list]
 
@@ -227,12 +220,7 @@ class Govern(Module):
     def get_govern_param(self, module, name):
         """ 获取可治理参数的值
         """
-        return self.web3.pip.get_govern_param(module, name)
-
-    def govern_param_list(self, module=''):
-        """ 获取可治理参数列表信息
-        """
-        return self.web3.pip.govern_param_list(module)
+        return self.aide.web3.pip.get_govern_param(module, name)
 
 
 class ChainVersion(AttributeDict):
