@@ -9,4 +9,6 @@ class Graphql:
         self.client = get_gql(uri)
 
     def execute(self, content):
+        """ 执行GQL语句，并获取返回结果
+        """
         return self.client.execute(gql(content))
